pygments.lexer.RegexLexerMeta

pygments :: lexer :: RegexLexerMeta :: Class RegexLexerMeta |
[hide private]
[frames] | no frames]

# Type RegexLexerMeta

    object --+
             |
          type --+
                 |
         LexerMeta --+
                     |
                    RegexLexerMeta

Metaclass for RegexLexer, creates the self._tokens attribute from self.tokens on the first instantiation.

Instance Methods | [hide private]
_process_state(cls, unprocessed, processed, state) |
process_tokendef(cls, name, tokendefs=None) |
__call__(cls, *args, **kwds) x(...) |
Inherited from `type`: `__cmp__`, `__delattr__`, `__getattribute__`, `__hash__`, `__repr__`, `__setattr__`, `__subclasses__`, `mro` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__str__`

Static Methods | [hide private]
Inherited from `LexerMeta`: `__new__`

Properties | [hide private]
Inherited from `type`: `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details | [hide private]

### __call__(cls, *args, **kwds) (Call operator) |
x(...) Overrides: type.__call__ (inherited documentation)